Stan Math Library: stan/math/prim/mat/fun/trace_inv_quad_form_ldlt.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
trace_inv_quad_form_ldlt.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/LDLT_factor.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/prim/mat/fun/mdivide_left_ldlt.hpp>`
`#include <stan/math/prim/mat/fun/trace.hpp>`
`#include <stan/math/prim/mat/fun/transpose.hpp>`
`#include <stan/math/prim/mat/fun/multiply.hpp>`
`#include <stan/math/prim/scal/meta/is_var.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 , int R2, int C2, int R3, int C3>
boost::enable_if_c<!stan::is_var< T1 >::value &&!stan::is_var< T2 >::value, typename boost::math::tools::promote_args< T1, T2 >::type >::type | stan::math::trace_inv_quad_form_ldlt (const stan::math::LDLT_factor< T1, R2, C2 > &A, const Eigen::Matrix< T2, R3, C3 > &B)

[ Stan Home Page ] © 2011–2016, Stan Development Team.